from whistlepy.client.api.oauth import WhistleOAuthApi
from whistlepy.client.api.notification import WhistleNotificationApi
from whistlepy.client.api.organization import WhistleOrganizationApi
from whistlepy.client.api.geo import WhistleWifiLocApi
from whistlepy.client.api.label import WhistleLabelApi
